# APISpARC
API Specification Analysis for Risks and Compliance

API Sparc is a tool that will analyse API Specification for Security Risks and Compliance violations.

API Specification captures the design of an API and is an integral part of API development process. The design of an API is captured in various formats such as Swagger, OpenAPI, RAML, etc.

API Sparc analyses API specifications written in Swagger or OpenAPI format against the security best practices and then provides an assessment score and severity. The API Sparc tool also provides a language to codfiy your custom Risk and Compliance voilation rules too.

Learn more about the security best practices that is supported out of the box in this tool here - https://www.cloudvector.com/api-security-checklist-secure-api-design/
